Equality<E> class abstract

A generic equality relation on objects.

Constructors

Equality()
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

equals(E e1, E e2) → bool
Compare two elements for being equal.
hash(E e) → int
Get a hashcode of an element.
override
isValidKey(Object? o) → bool
Test whether an object is a valid argument to equals and hash.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited