TextDirection class

Represents directionality of text.

In most cases, it is preferable to use bidi_formatter.dart, which provides bidi functionality in the given directional context, instead of using bidi_utils.dart directly.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spanText → String
Textual representation of the directionality when used in span tag.
final
value → String
Textual representation of the directionality constant. One of 'LTR', 'RTL', or 'UNKNOWN'.
final

Methods

isDirectionChange(TextDirection otherDirection) → bool
Returns true if otherDirection is known to be different from this direction.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

LTR → const TextDirection
RTL → const TextDirection
UNKNOWN → const TextDirection