UnmodifiableSetMixin<E> class abstract mixin

Mixin class that implements a throwing version of all set operations that change the Set.

Implemented types
Available extensions

Constructors

UnmodifiableSetMixin()

Properties

average → double

Available on Iterable<int>, provided by the IterableIntegerExtension extension

The arithmetic mean of the elements of a non-empty iterable.
no setter
average → double

Available on Iterable<num>, provided by the IterableNumberExtension extension

The arithmetic mean of the elements of a non-empty iterable.
no setter
first → E
The first element.
no setterinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element, or null if the iterable is empty.
no setter
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
flattened → Iterable<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The sequential elements of each iterable in this iterable.
no setter
flattenedToList → List<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The sequential elements of each iterable in this iterable.
no setter
flattenedToSet → Set<T>

Available on Iterable<Iterable<T>>, provided by the IterableIterableExtension extension

The unique sequential elements of each iterable in this iterable.
no setter
hashCode → int
The hash code for this object.
no setterinherited
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Whether this collection has no elements.
no setterinherited
isNotEmpty → bool
Whether this collection has at least one element.
no setterinherited
iterator → Iterator<E>
An iterator that iterates over the elements of this set.
no setterinherited
last → E
The last element.
no setterinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element, or null if the iterable is empty.
no setter
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length → int
The number of elements in this Iterable.
no setterinherited
max → num

Available on Iterable<num>, provided by the IterableNumberExtension extension

A maximal element of the iterable.
no setter
max → T

Available on Iterable<T>, provided by the IterableComparableExtension extension

A maximal element of the iterable.
no setter
max → double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A maximal element of the iterable.
no setter
max → int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A maximal element of the iterable.
no setter
maxOrNull → int?

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull → double?

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull → T?

Available on Iterable<T>, provided by the IterableComparableExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
maxOrNull → num?

Available on Iterable<num>, provided by the IterableNumberExtension extension

A maximal element of the iterable, or null if the iterable is empty.
no setter
min → double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A minimal element of the iterable.
no setter
min → T

Available on Iterable<T>, provided by the IterableComparableExtension extension

A minimal element of the iterable.
no setter
min → int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A minimal element of the iterable.
no setter
min → num

Available on Iterable<num>, provided by the IterableNumberExtension extension

A minimal element of the iterable.
no setter
minOrNull → T?

Available on Iterable<T>, provided by the IterableComparableExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull → int?

Available on Iterable<int>, provided by the IterableIntegerExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull → double?

Available on Iterable<double>, provided by the IterableDoubleExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
minOrNull → num?

Available on Iterable<num>, provided by the IterableNumberExtension extension

A minimal element of the iterable, or null it the iterable is empty.
no setter
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → E
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element of the iterable, or null.
no setter
sum → double

Available on Iterable<double>, provided by the IterableDoubleExtension extension

The sum of the elements.
no setter
sum → num

Available on Iterable<num>, provided by the IterableNumberExtension extension

The sum of the elements.
no setter
sum → int

Available on Iterable<int>, provided by the IterableIntegerExtension extension

The sum of the elements.
no setter
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(E value) → bool
Throws an UnsupportedError; operations that change the set are disallowed.
override
addAll(Iterable<E> elements) → void
Throws an UnsupportedError; operations that change the set are disallowed.
override
any(bool test(E value)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<R>() → Set<T>
Provides a view of this set as a set of R instances.
inherited
clear() → void
Throws an UnsupportedError; operations that change the set are disallowed.
override
contains(Object? value) → bool
Whether value is in the set.
inherited
containsAll(Iterable<Object?> other) → bool
Whether this set contains all the elements of other.
inherited
difference(Set<Object?> other) → Set<E>
Creates a new set with the elements of this that are not in other.
inherited
elementAt(int index) → E
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The indexth element, or null if there is no such element.
every(bool test(E value)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(E element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
expandIndexed<R>(Iterable<R> expand(int index, T element)) → Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Expands each element and index to a number of elements in a new iterable.
firstWhere(bool test(E value), {E orElse()?}) → E
The first element that satisfies the given predicate test.
inherited
firstWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element whose value and index satisfies test.
firstWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The first element satisfying test, or null if there are none.
fold<T>(T initialValue, T combine(T previousValue, E element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
foldIndexed<R>(R initialValue, R combine(int index, R previous, T element)) → R

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with a value and the current index.
followedBy(Iterable<E> other) → Iterable<E>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(E element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
forEachIndexed(void action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element.
forEachIndexedWhile(bool action(int index, T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element and index as long as desired.
forEachWhile(bool action(T element)) → void

Available on Iterable<T>, provided by the IterableExtension extension

Takes an action for each element as long as desired.
groupFoldBy<K, G>(K keyOf(T element), G combine(G? previous, T element)) → Map<K, G>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements by keyOf then folds the elements in each group.
groupListsBy<K>(K keyOf(T element)) → Map<K, List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into lists by keyOf.
groupSetsBy<K>(K keyOf(T element)) → Map<K, Set<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Groups elements into sets by keyOf.
intersection(Set<Object?> other) → Set<E>
Creates a new set which is the intersection between this set and other.
inherited
isSorted([Comparator<T>? compare]) → bool

Available on Iterable<T>, provided by the IterableComparableExtension extension

Whether the elements are sorted by the compare ordering.
isSorted(Comparator<T> compare) → bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by the compare ordering.
isSortedBy<K extends Comparable<K>>(K keyOf(T element)) → bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are sorted by their keyOf property.
isSortedByCompare<K>(K keyOf(T element), Comparator<K> compare) → bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether the elements are compare-sorted by their keyOf property.
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastBy<K>(K key(T)) → Map<K, T>

Available on Iterable<T>, provided by the IterableExtension extension

Associates the elements in this by the value returned by key.
lastWhere(bool test(E value), {E orElse()?}) → E
The last element that satisfies the given predicate test.
inherited
lastWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element whose index and value satisfies test.
lastWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The last element satisfying test, or null if there are none.
lookup(Object? object) → E?
If an object equal to object is in the set, return it.
inherited
map<T>(T toElement(E e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
mapIndexed<R>(R convert(int index, T element)) → Iterable<R>

Available on Iterable<T>, provided by the IterableExtension extension

Maps each element and its index to a new value.
none(bool test(T element)) → bool

Available on Iterable<T>, provided by the IterableExtension extension

Whether no element satisfies test.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(E combine(E value, E element)) → E
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
reduceIndexed(T combine(int index, T previous, T element)) → T

Available on Iterable<T>, provided by the IterableExtension extension

Combine the elements with each other and the current index.
remove(Object? value) → bool
Throws an UnsupportedError; operations that change the set are disallowed.
override
removeAll(Iterable elements) → void
Throws an UnsupportedError; operations that change the set are disallowed.
override
removeWhere(bool test(E value)) → void
Throws an UnsupportedError; operations that change the set are disallowed.
override
retainAll(Iterable elements) → void
Throws an UnsupportedError; operations that change the set are disallowed.
override
retainWhere(bool test(E value)) → void
Throws an UnsupportedError; operations that change the set are disallowed.
override
sample(int count, [Random? random]) → List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Selects count elements at random from this iterable.
shuffled([Random? random]) → List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a shuffled list of the elements of the iterable.
singleWhere(bool test(E value), {E orElse()?}) → E
The single element that satisfies test.
inherited
singleWhereIndexedOrNull(bool test(int index, T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
singleWhereOrNull(bool test(T element)) → T?

Available on Iterable<T>, provided by the IterableExtension extension

The single element satisfying test.
skip(int count) → Iterable<E>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(E value)) → Iterable<E>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
slices(int length) → Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Contiguous slices of this with the given length.
sorted([Comparator<T>? compare]) → List<T>

Available on Iterable<T>, provided by the IterableComparableExtension extension

Creates a sorted list of the elements of the iterable.
sorted(Comparator<T> compare) → List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedBy<K extends Comparable<K>>(K keyOf(T element)) → List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
sortedByCompare<K>(K keyOf(T element), Comparator<K> compare) → List<T>

Available on Iterable<T>, provided by the IterableExtension extension

Creates a sorted list of the elements of the iterable.
splitAfter(bool test(T element)) → Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements.
splitAfterIndexed(bool test(int index, T element)) → Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks after some elements and indices.
splitBefore(bool test(T element)) → Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements.
splitBeforeIndexed(bool test(int index, T element)) → Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks before some elements and indices.
splitBetween(bool test(T first, T second)) → Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements.
splitBetweenIndexed(bool test(int index, T first, T second)) → Iterable<List<T>>

Available on Iterable<T>, provided by the IterableExtension extension

Splits the elements into chunks between some elements and indices.
take(int count) → Iterable<E>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(E value)) → Iterable<E>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<E>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<E>
Creates a Set with the same elements and behavior as this Set.
inherited
toString() → String
A string representation of this object.
inherited
union(Set<E> other) → Set<E>
Creates a new set which contains all the elements of this set and other.
inherited
where(bool test(E value)) → Iterable<E>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereIndexed(bool test(int index, T element)) → Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index satisfies test.
whereNot(bool test(T element)) → Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements that do not satisfy test.
whereNotIndexed(bool test(int index, T element)) → Iterable<T>

Available on Iterable<T>, provided by the IterableExtension extension

The elements whose value and index do not satisfy test.
whereNotNull() → Iterable<T>

Available on Iterable<T?>, provided by the IterableNullableExtension extension

The non-null elements of this Iterable.
whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited