archery/core/application
library
Classes
-
App
-
The main application class that serves as a singleton service container
and lifecycle manager for the Archery framework.
Enums
-
AppStatus
-
Enum representing the lifecycle status of the App instance.
Extensions
-
Boot
on App
-
-
ContainerOperations
on App
-
Extension on App providing syntactic sugar for dependency resolution and binding.
-
GetConfig
on App
-
Convenience accessors for resolving configuration from the IoC container.
-
GetLoggers
on App
-
Convenience accessors for common framework/application loggers.