MaxRule class

Validation rule that restricts a value to a maximum character length.

Example:

final rule = MaxRule(255);
print(rule.limit); // 255

Constructors

MaxRule(int limit)
Creates a max-length rule using the given limit.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int
Maximum allowed character length.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited