MinRule class

Validation rule that enforces a minimum character length.

Example:

final rule = MinRule(8);
print(rule.limit); // 8

Constructors

MinRule(int limit)
Creates a min-length rule using the given limit.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int
Minimum required character length.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited