Rule enum

Built-in validation rules used by request validation.

Rule defines simple declarative validators such as required and email, and provides helpers for constructing parameterized rules like min, max, and unique.

Example:

final rules = [
  Rule.required,
  Rule.email,
  Rule.max(255),
];
Inheritance
Available extensions

Values

email → const Rule
required → const Rule

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

max(int value) → MaxRule
Creates a maximum-length validation rule.
min(int value) → MinRule
Creates a minimum-length validation rule.
unique<T extends Model>({required String column}) → UniqueRule<Model>
Creates a uniqueness validation rule for a model column.

Constants

values → const List<Rule>
A constant List of the values in this enum, in order of their declaration.