unique<T extends Model> static method
Creates a uniqueness validation rule for a model column.
This rule checks whether the provided value already exists in the given model column.
Example:
final rule = Rule.unique<User>(column: 'email');
Implementation
static UniqueRule unique<T extends Model>({required String column}) => UniqueRule<T>(column: column);