IncludeNode class

A reference to another template that should be rendered inline.

Inheritance

Constructors

IncludeNode(String templateName, String? dataJson)
Creates an include node for templateName.

Properties

dataJson → String?
Optional raw data text supplied after the template name.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
templateName → String
The dot-delimited name of the included template.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited