VariableExpr class

A reference to a value in the render context.

Dotted references such as user.profile.name are stored as individual path segments and resolved during rendering.

Inheritance

Constructors

VariableExpr(List<String> path)
Creates a variable reference from path.

Properties

hashCode → int
The hash code for this object.
no setterinherited
path → List<String>
The ordered segments of the dotted variable path.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited