RoleType enum

Built-in role names used by the framework.

Example:

final role = RoleType.admin;
print(role.name); // admin
Inheritance
Available extensions

Values

admin → const RoleType

Administrative role.

owner → const RoleType

Owner role.

staff → const RoleType

Staff role.

guest → const RoleType

Guest role.

Properties

description String
Returns the default description for the role.
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
Returns the lowercase role name.
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RoleType>
A constant List of the values in this enum, in order of their declaration.