GuestSession class
Middleware guard for routes intended only for guests (unauthenticated users).
If an auth session exists for the current request, the request is redirected to the dashboard. Otherwise the request continues.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
middleware(
HttpRequest request, Future< void> next()) → Future