S3HttpResponse class base

Raw HTTP response wrapper returned by low-level S3 requests.

Example:

final response = S3HttpResponse(200, Uint8List(0), headers);
print(response.statusCode);

Constructors

S3HttpResponse(int statusCode, Uint8List body, HttpHeaders headers)
Creates a raw S3 HTTP response wrapper.

Properties

body Uint8List
Response body bytes.
final
hashCode int
The hash code for this object.
no setterinherited
headers HttpHeaders
Response headers returned by S3.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
HTTP status code returned by S3.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited