EmailAddress class base
Represents an email address, optionally paired with a display name.
Example:
final address = EmailAddress('jane@example.com', name: 'Jane Doe');
print(address.toString()); // Jane Doe <jane@example.com>
Constructors
- EmailAddress(String email, {String? name})
- Optional display name. Creates an email address wrapper.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Serializes this address into a map form.
-
toString(
) → String -
Returns the address formatted for email headers.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited