SendEmailRequest class base
Describes an email send request for SES.
A request may contain plain-text and/or HTML bodies, optional CC/BCC recipients, optional attachments, reply-to settings, and a configuration set name.
Example:
final request = SendEmailRequest(
from: EmailAddress('noreply@example.com', name: 'Archery'),
to: [EmailAddress('jane@example.com')],
subject: 'Welcome',
textBody: 'Welcome to Archery',
htmlBody: '<h1>Welcome to Archery</h1>',
);
Constructors
-
SendEmailRequest({required EmailAddress from, required List<
EmailAddress> to, List<EmailAddress> ? cc, List<EmailAddress> ? bcc, required String subject, String? textBody, String? htmlBody, String? charset = 'UTF-8', List<EmailAttachment> ? attachments, String? replyTo, String? configurationSetName}) - Creates an SES email request.
Properties
-
attachments
→ List<
EmailAttachment> ? -
Optional email attachments.
final
-
bcc
→ List<
EmailAddress> ? -
Optional BCC recipients.
final
-
cc
→ List<
EmailAddress> ? -
Optional CC recipients.
final
- charset → String?
-
Charset used for message subject and body parts.
final
- configurationSetName → String?
-
Optional SES configuration set name.
final
- from → EmailAddress
-
Sender address.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- htmlBody → String?
-
Optional HTML body.
final
- replyTo → String?
-
Optional reply-to address.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subject → String
-
Email subject line.
final
- textBody → String?
-
Optional plain-text body.
final
-
to
→ List<
EmailAddress> -
Primary recipients.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited