SendEmailResponse class base
Result returned from a successful SES send operation.
Example:
final response = SendEmailResponse(
messageId: 'abc123',
requestId: 'req-123',
timestamp: DateTime.now(),
);
Constructors
- SendEmailResponse({required String messageId, required String requestId, required DateTime timestamp})
- Creates an SES send response wrapper.
-
SendEmailResponse.fromMap(Map<
String, dynamic> map) -
Creates a SendEmailResponse from an SES response map.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → String
-
SES message identifier.
final
- requestId → String
-
AWS request identifier.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Timestamp captured when the response was created.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited