SesClient class base
Low-level SES client that signs and sends API requests.
SesClient implements AWS Signature Version 4 for the SES Query API and
provides helpers for building standard and raw email payloads.
Example:
final client = SesClient(
SesConfig(
key: 'AKIA...',
secret: 'super-secret',
region: 'us-east-1',
),
);
Properties
Methods
-
getSendQuota(
) → Future< Map< String, dynamic> > - Retrieves the current SES send quota information.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
sendEmail(
SendEmailRequest request) → Future< SendEmailResponse> - Sends an email through SES.
-
sendSimpleEmail(
{required String from, required List< String> to, required String subject, String? body, String? htmlBody, List<String> ? cc, List<String> ? bcc}) → Future<SendEmailResponse> - Convenience wrapper for sending a basic email with string addresses.
-
testConnection(
) → Future< bool> - Tests connectivity to SES by attempting to fetch send quota data.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited