SesHttpResponse class base
Raw HTTP response wrapper used by the SES client internals.
Example:
final response = SesHttpResponse(200, '<xml />', {});
print(response.statusCode);
Constructors
Properties
- body → String
-
Raw response body as text.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Response headers keyed by lowercase header name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code returned by SES.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited